# Snapshots

Snapshots configuration is straightforward. Currently, it only sets `creation_rate` - period in minutes for creating new snapshots (30 minutes by default).

File `snapshots.yml` looks like this:

```yaml
creation_rate: 30
```
